package lcsb.mapviewer.annotation.data.serializer;

import java.io.IOException;
import java.util.Arrays;
import java.util.List;

import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.ser.FilterProvider;
import com.fasterxml.jackson.databind.ser.PropertyFilter;

import lcsb.mapviewer.annotation.data.MiRNA;
import lcsb.mapviewer.modelutils.serializer.CustomExceptFilter;

public class MiRNASerializer extends JsonSerializer<MiRNA> {

  @Override
  public void serialize(final MiRNA miRna, final JsonGenerator gen,
      final SerializerProvider serializers)
      throws IOException {
    PropertyFilter filter = null;
    FilterProvider provider = serializers.getConfig().getFilterProvider();
    if (provider != null) {
      filter = provider.findPropertyFilter("miRnaFilter", null);
    }

    gen.writeStartObject();

    for (final String string : availableColumns()) {
      String column = string.toLowerCase();
      Object value = null;
      switch (column) {
        case "id":
        case "idobject":
        case "name":
          value = miRna.getName();
          break;
        case "targets":
          value = miRna.getTargets();
          break;
        default:
          value = "Unknown column";
          break;
      }
      writeField(gen, string, value, filter);
    }

    gen.writeEndObject();
  }

  private void writeField(final JsonGenerator gen, final String field, final Object value, final PropertyFilter filter) throws IOException {
    if (filter == null
        || (filter instanceof CustomExceptFilter && ((CustomExceptFilter) filter).includeField(field))) {
      gen.writeObjectField(field, value);
    }
  }

  public static List<String> availableColumns() {
    return Arrays.asList("name", "id", "targets");

  }
}