package lcsb.mapviewer.annotation.cache;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;
import static org.mockito.ArgumentMatchers.anyString;
import static org.mockito.Mockito.when;

import java.util.List;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.mockito.Mockito;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.util.ReflectionTestUtils;
import org.w3c.dom.Node;

import lcsb.mapviewer.annotation.AnnotationTestFunctions;
import lcsb.mapviewer.model.cache.CacheType;
import lcsb.mapviewer.persist.dao.cache.CacheTypeDao;

public class CachableInterfaceTest extends AnnotationTestFunctions {

  @Autowired
  private List<Cacheable> interfaces;

  @Before
  public void setUp() throws Exception {
  }

  @After
  public void tearDown() throws Exception {
  }

  @Test
  public void testImplementationCacheExists() throws Exception {
    for (final Cacheable cachableInterface : interfaces) {
      assertNotNull("Cache type does not exist for type: " + cachableInterface, cachableInterface.getCacheType());
    }
  }

  @Test
  public void testGetWebPage() throws Exception {
    CachableInterfaceMock ci = new CachableInterfaceMock(CachableInterface.class);
    String result = ci.getWebPageContent("http://www.drugbank.ca/biodb/polypeptides/P21728");
    assertNotNull(result);
  }

  @Test
  public void testGetWebPage2() throws Exception {
    CachableInterfaceMock ci = new CachableInterfaceMock(CachableInterface.class);
    String result = ci.getWebPageContent("http://www.drugbank.ca/drugs/DB00091");
    assertNotNull(result);
  }

  @Test
  public void testGetWebPageGetCache() throws Exception {
    CachableInterfaceMock ci = new CachableInterfaceMock(CachableInterface.class);

    CacheTypeDao mock = Mockito.mock(CacheTypeDao.class);
    when(mock.getByClassName(anyString())).thenReturn(new CacheType());
    ReflectionTestUtils.setField(ci, "cacheTypeDao", mock);
    ci.setCache(new GeneralCache(null));

    String cacheKey = "https://www.google.com/";
    String result = ci.getWebPageContent(cacheKey);
    assertNotNull(result);
    String cacheValue = ci.getCacheValue(cacheKey);
    assertTrue(result.equals(cacheValue));
  }

  @Test
  public void testSetNode() throws Exception {
    CachableInterfaceMock ci = new CachableInterfaceMock(CachableInterface.class);

    CacheTypeDao mock = Mockito.mock(CacheTypeDao.class);
    when(mock.getByClassName(anyString())).thenReturn(new CacheType());
    ReflectionTestUtils.setField(ci, "cacheTypeDao", mock);

    String xml = "<xml><child/></xml>";
    ci.setCache(new GeneralCache(null));
    ci.setCacheNode("id", super.getNodeFromXmlString(xml));

    Node node = ci.getCacheNode("id");
    assertNotNull(node);
  }

  @Test
  public void testNewLinesGetWebPage() throws Exception {
    CachableInterfaceMock ci = new CachableInterfaceMock(CachableInterface.class);
    ci.setCache(null);
    String result = ci.getWebPageContent("http://google.com/");
    assertNotNull(result);
    assertTrue(result.contains("\n"));
  }
}
