package lcsb.mapviewer.annotation.cache;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertNull;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.annotation.Rollback;
import org.w3c.dom.Node;

import lcsb.mapviewer.annotation.AnnotationTestFunctions;
import lcsb.mapviewer.annotation.services.PubmedParser;
import lcsb.mapviewer.model.cache.CacheType;

@Rollback(true)
public class PermanentDatabaseLevelCacheWithoutTransactionTest extends AnnotationTestFunctions {

  @Autowired
  private PermanentDatabaseLevelCacheInterface permanentDatabaseLevelCache;

  private CacheType mockCacheType;

  @Before
  public void setUp() throws Exception {
    mockCacheType = cacheTypeDao.getByClassName(MockCacheInterface.class.getCanonicalName());
  }

  @After
  public void tearDown() throws Exception {
  }

  @Test(timeout = 15000)
  public void testRefresh() throws Exception {

    String query = "test query";
    String val = "halo";
    cache.setCachedQuery(query, mockCacheType, val);
    String res = cache.getStringByQuery(query, mockCacheType);
    assertNotNull(res);
    // for the first time value should be the same (it's not valid but cache
    // wasn't updated)
    assertEquals(val, res);
    // sleep a bit to wait for the second thread
    permanentDatabaseLevelCache.waitToFinishTasks();
    // for the second time it should change
    res = cache.getStringByQuery(query, mockCacheType);
    assertNotNull(res);
    assertFalse(val.equals(res));
  }

  @Test
  public void testRefreshNode() throws Exception {

    String query = "test query";
    String val = "<node><subnode>halo</subnode></node>";
    Node node = getNodeFromXmlString(val);
    cache.setCachedQuery(query, mockCacheType, node);
    Node res = cache.getXmlNodeByQuery(query, mockCacheType);

    assertNotNull(res);
    permanentDatabaseLevelCache.waitToFinishTasks();
    // for the second time it should change
    Node res2 = cache.getXmlNodeByQuery(query, mockCacheType);
    assertNotNull(res2);

    String strRes = nodeToString(res);
    String strRes2 = nodeToString(res2);
    assertFalse(strRes.equals(strRes2));
  }

  @Test
  public void testByQuery() throws Exception {
    String xml = "<hello/>";
    String query = "blabla";

    String xml2 = "<hello23/>";

    CacheType type = cacheTypeDao.getByClassName(PubmedParser.class.getCanonicalName());

    Node sourceNode = getNodeFromXmlString(xml);
    Node sourceNode2 = getNodeFromXmlString(xml2);
    cache.removeByQuery(query, type);

    Node node = cache.getXmlNodeByQuery(query, type);
    assertNull(node);

    cache.setCachedQuery(query, type, sourceNode);
    node = cache.getXmlNodeByQuery(query, type);
    assertNotNull(node);
    assertEquals("hello", node.getNodeName());

    cache.setCachedQuery(query, type, sourceNode2);
    node = cache.getXmlNodeByQuery(query, type);
    assertNotNull(node);
    assertEquals("hello23", node.getNodeName());
  }

}
