package lcsb.mapviewer.converter.graphics.bioentity.element.species;

import java.awt.Color;
import java.awt.Font;
import java.awt.Graphics2D;
import java.awt.Shape;
import java.awt.geom.Ellipse2D;

import lcsb.mapviewer.converter.graphics.ConverterParams;
import lcsb.mapviewer.converter.graphics.DrawableConverter;
import lcsb.mapviewer.model.map.species.field.StructuralState;

public class StructuralStateConverter extends DrawableConverter<StructuralState> {

  public void draw(final StructuralState state, final Graphics2D graphics, final ConverterParams params) {
    if (state == null || !isVisible(state.getSpecies(), params)) {
      return;
    }

    double width = state.getWidth();
    double height = state.getHeight();

    Shape ellipse = getStructuralStateShape(state);
    Color c = graphics.getColor();
    graphics.setColor(Color.WHITE);
    graphics.fill(ellipse);
    graphics.setColor(c);
    graphics.draw(ellipse);
    if (!state.getValue().equals("")) {
      Font tmpFont = graphics.getFont();
      Font font = new Font(Font.SANS_SERIF, 0, state.getFontSize().intValue());
      graphics.setFont(font);

      width = graphics.getFontMetrics().stringWidth(state.getValue());
      height = graphics.getFontMetrics().getAscent() - graphics.getFontMetrics().getDescent();

      double x = state.getPosition().getX() + (state.getWidth() - width) / 2;
      double y = state.getPosition().getY() + (state.getHeight() + height) / 2;

      graphics.drawString(state.getValue(), (int) x, (int) y);
      graphics.setFont(tmpFont);
    }

  }

  Shape getStructuralStateShape(final StructuralState state) {
    return new Ellipse2D.Double(
        state.getPosition().getX(),
        state.getPosition().getY(),
        state.getWidth(),
        state.getHeight());
  }

}
