#!/bin/bash

versionCompLte() {
    [  "$1" = "`echo -e "$1\n$2" | sort -V | head -n1`" ]
}


versionCompLt() {
    [ "$1" = "$2" ] && return 1 || versionCompLte $1 $2
}

#Where source file of the debian package should be placed
SRC_DIR=debian/src

#File that should be deployed on tomcat
TOMCAT_FILE=web/target/*.war

ROOT_DIR=`pwd`

# where dn script files should be stored on the debian system
LOG_FILE="\/var\/log\/minerva-install.log"

#clean build directories
rm -rf $SRC_DIR
rm -rf debian/minerva*

#recreate directory
mkdir $SRC_DIR

#copy  war file
cp $TOMCAT_FILE $SRC_DIR/minerva.war

#copy manual documentation
cp debian/description.txt $SRC_DIR/minerva.txt
gzip -n $SRC_DIR/minerva.txt

#copy configuration of logrotate
cp debian/logrotate/* $SRC_DIR/

touch $SRC_DIR/pgsql

cp debian/scripts/common.sh $SRC_DIR/

#copy changelog file
cp CHANGELOG $ROOT_DIR/debian/template/changelog

current_version=`cat CHANGELOG |grep minerva |head -1 | cut -f2 -d'(' | cut -f1 -d')'`

echo "Current version: " $current_version

#dh_make requires directory name to be like <package>-<version>
# this points to the directory
DEBIAN_DIR=debian/minerva-$current_version/

mkdir $DEBIAN_DIR

# copy all source files to this directory
cp $SRC_DIR/* $DEBIAN_DIR

#because dh_make works only from within directory where
#package data will be generated we need to change it
cd $DEBIAN_DIR
#this should be improved (to include src properly)
dh_make -s --createorig -e piotr.gawron@uni.lu -y -t $ROOT_DIR/debian/template 

echo "1.0" > debian/source/format

#remove example files generated by dh_make
find -name '*.ex' ! -name 'minerva*' -type f -exec rm -f {} +

#our pre/post inst/rm scripts use __CURRENT_VERSION__ as a version of currently
#installed package

sed -i "s/__CURRENT_VERSION__/$current_version/g" common.sh
sed -i "s/__LOG_FILE__/$LOG_FILE/g" common.sh

sed -i -e "1r common.sh" debian/config
sed -i -e "1r common.sh" debian/postinst
sed -i -e "1r common.sh" debian/postrm
sed -i -e "1r common.sh" debian/preinst
sed -i -e "1r common.sh" debian/prerm




#set proper architecture
arch=`dpkg --print-architecture`
echo "Architecture: $arch" >>debian/control

#set manual file
echo minerva.txt.gz /usr/share/doc/minerva/minerva.txt.gz >> debian/install;

#logrotate configuration for minerva log4j connector
echo minerva /etc/logrotate.d >> debian/install;

#remove some sample file
rm debian/*.EX
rm debian/*.ex

#build debian package
debuild -us -uc

# remove temporary changelog
rm $ROOT_DIR/debian/template/changelog
