package lcsb.mapviewer.commands;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.awt.geom.Line2D;
import java.awt.geom.Point2D;

import org.junit.Test;

import lcsb.mapviewer.common.Configuration;
import lcsb.mapviewer.model.graphics.PolylineData;
import lcsb.mapviewer.model.map.model.Model;
import lcsb.mapviewer.model.map.reaction.Product;
import lcsb.mapviewer.model.map.reaction.Reactant;
import lcsb.mapviewer.model.map.reaction.Reaction;
import lcsb.mapviewer.model.map.reaction.type.TransportReaction;
import lcsb.mapviewer.model.map.species.Protein;
import lcsb.mapviewer.model.map.species.field.BindingRegion;
import lcsb.mapviewer.model.map.species.field.StructuralState;

public class MoveCommandTest extends CommandTestFunctions {

  @Test
  public void testMoveReaction() throws CommandExecutionException {
    Model model = super.createSimpleModel();

    Reaction r = new TransportReaction("re");
    Reactant reactant = new Reactant(model.getSpeciesList().get(0));
    reactant.setLine(new PolylineData(new Point2D.Double(0, 10), new Point2D.Double(0, 20)));
    r.addReactant(reactant);
    Product product = new Product(model.getSpeciesList().get(1));
    product.setLine(new PolylineData(new Point2D.Double(0, 30), new Point2D.Double(0, 40)));
    r.addProduct(product);
    r.setLine(new PolylineData(new Point2D.Double(0, 20), new Point2D.Double(0, 30)));

    model.addReaction(r);

    new MoveCommand(model, 10, 20).execute();
    for (final Line2D line : r.getLines()) {
      assertTrue(line.getX1() > 0);
      assertTrue(line.getX2() > 0);
      assertTrue(line.getY1() > 10);
      assertTrue(line.getY2() > 10);
    }

  }

  @Test
  public void testMoveProtein() throws CommandExecutionException {
    Model model = super.createSimpleModel();

    Protein protein = createProtein();

    super.assignCoordinates(10, 20, 100, 100, protein);

    BindingRegion bindingRegion = new BindingRegion();
    bindingRegion.setPosition(new Point2D.Double(30, 20));
    protein.addBindingRegion(bindingRegion);

    StructuralState state = new StructuralState();
    state.setPosition(new Point2D.Double(40, 20));
    protein.setStructuralState(state);

    model.addElement(protein);

    new MoveCommand(model, 10, 20).execute();

    assertEquals(20, protein.getX(), Configuration.EPSILON);
    assertEquals(40, protein.getY(), Configuration.EPSILON);
    assertEquals(new Point2D.Double(40, 40), bindingRegion.getPosition());
    assertEquals(new Point2D.Double(50, 40), state.getPosition());
  }

}
