package lcsb.mapviewer.commands.properties;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import lcsb.mapviewer.commands.CommandTestFunctions;
import lcsb.mapviewer.model.map.model.Model;
import lcsb.mapviewer.model.map.model.ModelComparator;
import lcsb.mapviewer.model.map.species.Element;

public class ChangeElementAbbreviationCommandTest extends CommandTestFunctions {

  private Model model;

  private ModelComparator modelComparator = new ModelComparator();

  @Before
  public void setUp() throws Exception {
    model = createSimpleModel();
  }

  @After
  public void tearDown() throws Exception {
  }

  @Test
  public void testChangeAliasAbbreviation() throws Exception {
    Element alias = model.getElementByElementId("alias_id");
    ChangeElementAbbreviationCommand command = new ChangeElementAbbreviationCommand(model, alias, "test");
    assertFalse("test".equalsIgnoreCase(alias.getAbbreviation()));
    command.execute();
    assertTrue(alias.getAbbreviation().equalsIgnoreCase("test"));
  }

  @Test
  public void testUndo() throws Exception {
    Model model2 = createSimpleModel();
    Element alias = model.getElementByElementId("alias_id");

    // models should be equal before move
    assertEquals(0, modelComparator.compare(model, model2));

    ChangeElementAbbreviationCommand command = new ChangeElementAbbreviationCommand(model, alias, "test");
    command.execute();

    // after move models should be different
    assertTrue(0 != modelComparator.compare(model, model2));

    // undo command
    command.undo();

    // after undo they should be the same again
    assertEquals(0, modelComparator.compare(model, model2));

    command.redo();

    // after redo they should be different again
    assertTrue(0 != modelComparator.compare(model, model2));
  }

}
