package lcsb.mapviewer.model.map.species.field;

import java.awt.Color;
import java.awt.geom.Point2D;
import java.io.Serializable;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.DiscriminatorColumn;
import javax.persistence.DiscriminatorType;
import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Inheritance;
import javax.persistence.InheritanceType;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.hibernate.annotations.Type;

import lcsb.mapviewer.common.exception.NotImplementedException;
import lcsb.mapviewer.model.map.Drawable;
import lcsb.mapviewer.model.map.species.Species;

/**
 * This class represent modification residue in a {@link Species}.
 * 
 * @author Piotr Gawron
 * 
 */

@Entity
@Inheritance(strategy = InheritanceType.SINGLE_TABLE)
@DiscriminatorColumn(name = "modification_type", discriminatorType = DiscriminatorType.STRING)
@DiscriminatorValue("GENERIC_MODIFICATION_RESIDUE")
public abstract class ModificationResidue implements Serializable, Drawable {

  /**
   * 
   */
  private static final long serialVersionUID = 1L;

  /**
   * Default class logger.
   */
  @SuppressWarnings("unused")
  private static Logger logger = LogManager.getLogger();

  /**
   * Unique identifier in the database.
   */
  @Id
  @GeneratedValue(strategy = GenerationType.IDENTITY)
  private int id;

  /**
   * Identifier of the modification. Must be unique in single map model.
   */
  @Column(length = 255)
  private String idModificationResidue = "";

  /**
   * Name of the modification.
   */
  @Column(length = 255)
  private String name = "";

  @Type(type = "lcsb.mapviewer.persist.mapper.Point2DMapper")
  private Point2D position = null;

  @Column(nullable = false)
  private Integer z;

  /**
   * Species to which this modification belong to.
   */
  @ManyToOne(fetch = FetchType.LAZY, cascade = CascadeType.ALL)
  @JoinColumn(name = "idSpeciesDb", nullable = false)
  private Species species;

  @Type(type = "lcsb.mapviewer.persist.mapper.ColorMapper")
  @Column(nullable = false)
  private Color borderColor;

  /**
   * Default constructor.
   */
  public ModificationResidue() {
  }

  /**
   * Constructor that initialize object with the data taken from the parameter.
   * 
   * @param mr
   *          original object from which data is taken
   */
  public ModificationResidue(final ModificationResidue mr) {
    this.idModificationResidue = mr.idModificationResidue;
    this.name = mr.name;
    this.position = mr.position;
    this.z = mr.z;
    this.borderColor = mr.borderColor;
  }

  public ModificationResidue(final String modificationId) {
    this.idModificationResidue = modificationId;
  }

  /**
   * @return the idModificationResidue
   * @see #id
   */
  public int getId() {
    return id;
  }

  /**
   * @param id
   *          the idModificationResidue to set
   * @see #id
   */
  public void setId(final int id) {
    this.id = id;
  }

  /**
   * @return the id
   * @see #idModificationResidue
   */
  public String getIdModificationResidue() {
    return idModificationResidue;
  }

  /**
   * @param idModificationResidue
   *          the id to set
   * @see #idModificationResidue
   */
  public void setIdModificationResidue(final String idModificationResidue) {
    this.idModificationResidue = idModificationResidue;
  }

  /**
   * @return the name
   * @see #name
   */
  public String getName() {
    return name;
  }

  /**
   * @param name
   *          the name to set
   * @see #name
   */
  public void setName(final String name) {
    this.name = name;
  }

  /**
   * @return the species
   * @see #species
   */
  public Species getSpecies() {
    return species;
  }

  /**
   * @param species
   *          the species to set
   * @see #species
   */
  public void setSpecies(final Species species) {
    this.species = species;
  }

  public Point2D getPosition() {
    return position;
  }

  public void setPosition(final Point2D position) {
    this.position = position;
  }

  public ModificationResidue copy() {
    throw new NotImplementedException();
  }

  @Override
  public Integer getZ() {
    return z;
  }

  @Override
  public void setZ(final Integer z) {
    this.z = z;
  }

  @Override
  public String getElementId() {
    return getIdModificationResidue();
  }

  @Override
  public Color getBorderColor() {
    return borderColor;
  }

  public void setBorderColor(final Color borderColor) {
    this.borderColor = borderColor;
  }
}
