package lcsb.mapviewer.model.map.species.field;

import java.awt.Color;
import java.awt.geom.Point2D;
import java.io.Serializable;
import java.text.DecimalFormat;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.OneToOne;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.hibernate.annotations.Type;

import lcsb.mapviewer.model.map.Drawable;
import lcsb.mapviewer.model.map.species.Species;

/**
 * This class represent structural state of a {@link Species}.
 * 
 * @author Piotr Gawron
 * 
 */

@Entity
public class StructuralState implements Serializable, Drawable {

  private static final long serialVersionUID = 1L;

  @SuppressWarnings("unused")
  private static Logger logger = LogManager.getLogger();

  @Id
  @GeneratedValue(strategy = GenerationType.IDENTITY)
  private int id;

  @Column(nullable = false)
  private String value;

  @Type(type = "lcsb.mapviewer.persist.mapper.Point2DMapper")
  @Column(nullable = false)
  private Point2D position = null;

  @Column(nullable = false)
  private Integer z;

  @Column(nullable = false)
  private Double width;

  @Column(nullable = false)
  private Double height;

  @Column(nullable = false)
  private Double fontSize;

  @OneToOne(fetch = FetchType.LAZY, cascade = javax.persistence.CascadeType.ALL, mappedBy = "structuralState")
  private Species species;

  public StructuralState() {
  }

  /**
   * Constructor that initialize object with the data taken from the parameter.
   * 
   * @param mr
   *          original object from which data is taken
   */
  public StructuralState(final StructuralState mr) {
    this.value = mr.getValue();
    this.position = mr.position;
    this.width = mr.getWidth();
    this.height = mr.getHeight();
    this.fontSize = mr.getFontSize();
    this.z = mr.getZ();
  }

  public Species getSpecies() {
    return species;
  }

  public void setSpecies(final Species species) {
    this.species = species;
  }

  public Point2D getPosition() {
    return position;
  }

  public void setPosition(final Point2D position) {
    this.position = position;
  }

  public StructuralState copy() {
    return new StructuralState(this);
  }

  public String getValue() {
    return value;
  }

  public void setValue(final String value) {
    this.value = value;
  }

  @Override
  public String toString() {
    DecimalFormat format = new DecimalFormat("#.##");
    String positionString = "Point2D[null]";
    if (getPosition() != null) {
      positionString = "Point2D[" + format.format(getPosition().getX()) + "," + format.format(getPosition().getY())
          + "]";
    }
    String result = getValue() + "," + positionString;
    return result;
  }

  public Double getWidth() {
    return width;
  }

  public void setWidth(final Double width) {
    this.width = width;
  }
  
  public void setWidth(final Integer width) {
    this.width = width.doubleValue();
  }

  public Double getHeight() {
    return height;
  }

  public void setHeight(final Double height) {
    this.height = height;
  }

  public void setHeight(final Integer height) {
    this.height = height.doubleValue();
  }

  public Double getFontSize() {
    return fontSize;
  }

  public void setFontSize(final Double fontSize) {
    this.fontSize = fontSize;
  }

  public void setFontSize(final int fontSize) {
    this.fontSize = (double) fontSize;
  }

  public Point2D getCenter() {
    return new Point2D.Double(position.getX() + width / 2, position.getY() + height / 2);
  }

  @Override
  public Integer getZ() {
    return z;
  }

  @Override
  public void setZ(final Integer z) {
    this.z = z;
  }

  @Override
  public String getElementId() {
    return id + "";
  }

  @Override
  public double getSize() {
    return width * height;
  }

  @Override
  public Color getBorderColor() {
    return Color.BLACK;
  }

}
