package lcsb.mapviewer.model.map.species.field;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import lcsb.mapviewer.common.Comparator;
import lcsb.mapviewer.common.Configuration;
import lcsb.mapviewer.common.comparator.DoubleComparator;
import lcsb.mapviewer.common.comparator.IntegerComparator;
import lcsb.mapviewer.common.comparator.PointComparator;
import lcsb.mapviewer.common.comparator.StringComparator;

public class StructuralStateComparator extends Comparator<StructuralState> {

  private static Logger logger = LogManager.getLogger();

  private final StringComparator stringComparator;
  private final PointComparator pointComparator;
  private final DoubleComparator doubleComparator;
  private final IntegerComparator integerComparator;

  /**
   * Default constructor.
   */
  public StructuralStateComparator() {
    this(Configuration.EPSILON);
  }

  public StructuralStateComparator(final double epsilon) {
    super(StructuralState.class);
    stringComparator = new StringComparator();
    pointComparator = new PointComparator(epsilon);
    doubleComparator = new DoubleComparator();
    integerComparator = new IntegerComparator();
  }

  @Override
  protected int internalCompare(final StructuralState arg0, final StructuralState arg1) {
    if (stringComparator.compare(arg0.getValue(), arg1.getValue()) != 0) {
      return stringComparator.compare(arg0.getValue(), arg1.getValue());
    }
    if (pointComparator.compare(arg0.getPosition(), arg1.getPosition()) != 0) {
      logger.debug("position different: " + arg0.getPosition() + ", " + arg1.getPosition());
      return pointComparator.compare(arg0.getPosition(), arg1.getPosition());
    }

    if (doubleComparator.compare(arg0.getWidth(), arg1.getWidth()) != 0) {
      logger.debug("width different: " + arg0.getWidth() + ", " + arg1.getWidth());
      return doubleComparator.compare(arg0.getWidth(), arg1.getWidth());
    }
    if (doubleComparator.compare(arg0.getHeight(), arg1.getHeight()) != 0) {
      logger.debug("height different: " + arg0.getHeight() + ", " + arg1.getHeight());
      return doubleComparator.compare(arg0.getHeight(), arg1.getHeight());
    }

    if (integerComparator.compare(arg0.getZ(), arg1.getZ()) != 0) {
      logger.debug("z different: " + arg0.getZ() + ", " + arg1.getZ());
      return integerComparator.compare(arg0.getZ(), arg1.getZ());
    }

    return 0;
  }

}
