package lcsb.mapviewer.modelutils.serializer.model.map;

import java.io.IOException;
import java.util.function.Function;

import org.apache.commons.lang3.math.NumberUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.google.common.base.Objects;

import lcsb.mapviewer.model.Article;
import lcsb.mapviewer.model.map.MiriamData;
import lcsb.mapviewer.model.map.MiriamType;

public class MiriamDataSerializer extends JsonSerializer<MiriamData> {

  private static transient Logger logger = LogManager.getLogger();

  private Function<MiriamData, String> getUrl;
  private Function<MiriamData, Article> getArticle;

  public MiriamDataSerializer(final Function<MiriamData, String> getUrl, final Function<MiriamData, Article> getArticle) {
    this.getUrl = getUrl;
    this.getArticle = getArticle;
  }

  @Override
  public void serialize(final MiriamData annotation, final JsonGenerator gen,
      final SerializerProvider serializers)
      throws IOException {
    gen.writeStartObject();
    if (annotation.getDataType() != null && annotation.getDataType().getUris().size() > 0) {
      try {
        gen.writeStringField("link", getUrl.apply(annotation));
      } catch (final Exception e) {
        logger.error("Problem with miriam: " + annotation, e);
      }
    }
    if (Objects.equal(MiriamType.PUBMED, annotation.getDataType())) {
      if (NumberUtils.isDigits(annotation.getResource())) {
        try {
          gen.writeObjectField("article", getArticle.apply(annotation));
        } catch (final Exception e) {
          logger.error("Problem with accessing info about pubmed", e);
        }
      } else {
        logger.error("Invalid pubmed identifier: " + annotation.getResource());
      }
    }
    gen.writeObjectField("type", annotation.getDataType());
    gen.writeStringField("resource", annotation.getResource());
    gen.writeNumberField("id", annotation.getId());

    if (annotation.getAnnotator() != null) {
      gen.writeStringField("annotatorClassName", annotation.getAnnotator().getName());
    } else {
      gen.writeStringField("annotatorClassName", "");
    }
    gen.writeEndObject();
  }
}