package lcsb.mapviewer.persist.dao.map;

import java.util.ArrayList;
import java.util.List;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.stereotype.Repository;

import lcsb.mapviewer.common.Pair;
import lcsb.mapviewer.model.Project;
import lcsb.mapviewer.model.map.BioEntity;
import lcsb.mapviewer.model.map.model.ModelData;
import lcsb.mapviewer.model.map.reaction.Reaction;
import lcsb.mapviewer.model.map.species.Element;
import lcsb.mapviewer.model.overlay.DataOverlay;
import lcsb.mapviewer.model.overlay.DataOverlayEntry;
import lcsb.mapviewer.model.user.User;
import lcsb.mapviewer.persist.dao.BaseDao;

@Repository
public class DataOverlayDao extends BaseDao<DataOverlay> {

  @SuppressWarnings("unused")
  private Logger logger = LogManager.getLogger();

  public DataOverlayDao() {
    super(DataOverlay.class);
  }

  public List<DataOverlay> getByProject(final Project project) {
    List<DataOverlay> layouts = getElementsByParameter("project_id", project.getId());
    for (final DataOverlay layout : layouts) {
      refresh(layout);
    }
    return layouts;
  }

  public List<Pair<Element, DataOverlayEntry>> getElementsForModels(final int overlayId, final List<ModelData> maps) {
    return getElementsForModels(overlayId, maps, new ArrayList<>());
  }

  public List<Pair<Element, DataOverlayEntry>> getElementsForModels(final int overlayId, final List<ModelData> maps,
      final List<Integer> elementIdentifiers) {
    List<?> list = getElementsFromDatabase(overlayId, maps, elementIdentifiers, "entry, element");

    List<Pair<Element, DataOverlayEntry>> result = new ArrayList<>();
    for (Object object : list) {
      Object[] objects = (Object[]) object;
      Element element = (Element) objects[1];
      DataOverlayEntry entry = (DataOverlayEntry) objects[0];
      if (matchType(element, entry)) {
        result.add(new Pair<>(element, entry));
      }
    }
    return result;
  }

  public List<Pair<Element, DataOverlayEntry>> getElementReferencesForModels(final int overlayId, final List<ModelData> maps) {
    return getElementReferencesForModels(overlayId, maps, new ArrayList<>());
  }

  public List<Pair<Element, DataOverlayEntry>> getElementReferencesForModels(final int overlayId, final List<ModelData> maps,
      final List<Integer> elementIdentifiers) {
    List<?> list = getElementsFromDatabase(overlayId, maps, elementIdentifiers, "entry, element.id");

    List<Pair<Element, DataOverlayEntry>> result = new ArrayList<>();
    for (Object object : list) {
      Object[] objects = (Object[]) object;
      DataOverlayEntry entry = (DataOverlayEntry) objects[0];
      Element element = getSession().load(Element.class, (Integer) (objects[1]));

      if (matchType(element, entry)) {
        result.add(new Pair<>(element, entry));
      }
    }
    return result;
  }

  public List<Pair<Reaction, DataOverlayEntry>> getReactionsForModels(final int overlayId, final List<ModelData> maps) {
    return getReactionsForModels(overlayId, maps, new ArrayList<>());
  }

  public List<Pair<Reaction, DataOverlayEntry>> getReactionsForModels(final int overlayId, final List<ModelData> maps,
      final List<Integer> reactionIdentifiers) {
    List<?> list = getReactionsFromDatabase(overlayId, maps, reactionIdentifiers, "entry, reaction");
    List<Pair<Reaction, DataOverlayEntry>> result = new ArrayList<>();
    for (Object object : list) {
      Object[] objects = (Object[]) object;
      Reaction element = (Reaction) objects[1];
      DataOverlayEntry entry = (DataOverlayEntry) objects[0];
      if (matchType(element, entry)) {
        result.add(new Pair<>(element, entry));
      }
    }
    return result;
  }

  public List<Pair<Reaction, DataOverlayEntry>> getReactionReferencesForModels(final int overlayId, final List<ModelData> maps) {
    return getReactionReferencesForModels(overlayId, maps, new ArrayList<>());
  }

  public List<Pair<Reaction, DataOverlayEntry>> getReactionReferencesForModels(final int overlayId, final List<ModelData> maps,
      final List<Integer> reactionIdentifiers) {
    List<?> list = getReactionsFromDatabase(overlayId, maps, reactionIdentifiers, "entry, reaction.id");
    List<Pair<Reaction, DataOverlayEntry>> result = new ArrayList<>();
    for (Object object : list) {
      Object[] objects = (Object[]) object;
      Reaction element = getSession().load(Reaction.class, (Integer) (objects[1]));
      DataOverlayEntry entry = (DataOverlayEntry) objects[0];
      if (matchType(element, entry)) {
        result.add(new Pair<>(element, entry));
      }
    }
    return result;
  }

  private boolean matchType(final BioEntity element, final DataOverlayEntry entry) {
    boolean add = entry.getTypes().size() == 0;
    for (Class<?> clazz : entry.getTypes()) {
      if (clazz.isAssignableFrom(element.getClass())) {
        add = true;
      }
    }
    return add;
  }

  private List<?> getElementsFromDatabase(final int overlayId, final List<ModelData> maps, final List<Integer> elementIdentifiers,
      final String columnNames) {
    String queryString = "select " + columnNames + " from " + DataOverlayEntry.class.getSimpleName()
        + " entry left join entry.compartments compartment left join entry.miriamData entry_miriam, "
        + Element.class.getSimpleName() + " element left join element.miriamData element_miriam"
        + " where element.model in :maps and entry.dataOverlay.id = :overlayId "
        + " and (%ELEMENT_NAME_PART%) "
        + " and (lower(element.model.name) = lower(entry.modelName) or entry.modelName='' or entry.modelName is null) "
        + " and (entry_miriam is null or "
        + "      (entry_miriam.dataType = element_miriam.dataType and lower(entry_miriam.resource) = lower(element_miriam.resource)) ) "
        + " and (compartment is null or"
        + "      element.compartment.id in (select id from " + Element.class.getSimpleName()
        + "      compartment_element where lower(compartment_element.name) = lower(compartment) and compartment_element.model in :maps)) "
        + " and (lower(element.elementId) = lower(entry.elementId) or entry.elementId='' or entry.elementId is null) ";
    if (elementIdentifiers.size() > 0) {
      queryString += " and (element.id in :elementId) ";
    }
    queryString += " group by entry, element";

    org.hibernate.query.Query<?> query1 = getSession()
        .createQuery(queryString.replace("%ELEMENT_NAME_PART%", "lower(element.name) = lower(entry.name) and entry.name <>''"))
        .setParameter("maps", maps)
        .setParameter("overlayId", overlayId);
    if (elementIdentifiers.size() > 0) {
      query1.setParameter("elementId", elementIdentifiers);
    }

    org.hibernate.query.Query<?> query2 = getSession()
        .createQuery(queryString.replace("%ELEMENT_NAME_PART%", "entry.name =''"))
        .setParameter("maps", maps)
        .setParameter("overlayId", overlayId);
    if (elementIdentifiers.size() > 0) {
      query2.setParameter("elementId", elementIdentifiers);
    }

    List<Object> list = new ArrayList<>(query1.list());
    list.addAll(query2.list());
    return list;
  }

  private List<?> getReactionsFromDatabase(final int overlayId, final List<ModelData> maps, final List<Integer> reactionIdentifiers,
      final String columnNames) {
    String queryString = "select " + columnNames + " from " + DataOverlayEntry.class.getSimpleName()
        + " entry left join entry.compartments compartment left join entry.miriamData entry_miriam, "
        + Reaction.class.getSimpleName() + " reaction left join reaction.miriamData reaction_miriam"
        + " where reaction.model in :maps and entry.dataOverlay.id = :overlayId "
        + " and (%REACTION_NAME_PART%) "
        + " and (lower(reaction.model.name) = lower(entry.modelName) or entry.modelName='' or entry.modelName is null) "
        + " and (entry_miriam is null or "
        + "      (entry_miriam.dataType = reaction_miriam.dataType and lower(entry_miriam.resource) = lower(reaction_miriam.resource)) ) "
        + " and (lower(reaction.idReaction) = lower(entry.elementId) or entry.elementId='' or entry.elementId is null) ";
    if (reactionIdentifiers.size() > 0) {
      queryString += " and (reaction.id in :reactionId) ";
    }

    queryString += " group by entry, reaction";

    org.hibernate.query.Query<?> query1 = getSession()
        .createQuery(queryString.replace("%REACTION_NAME_PART%", "lower(reaction.name) = lower(entry.name) and entry.name <>''"))
        .setParameter("maps", maps)
        .setParameter("overlayId", overlayId);

    if (reactionIdentifiers.size() > 0) {
      query1.setParameter("reactionId", reactionIdentifiers);
    }

    org.hibernate.query.Query<?> query2 = getSession()
        .createQuery(queryString.replace("%REACTION_NAME_PART%", "entry.name =''"))
        .setParameter("maps", maps)
        .setParameter("overlayId", overlayId);

    if (reactionIdentifiers.size() > 0) {
      query2.setParameter("reactionId", reactionIdentifiers);
    }

    List<Object> list = new ArrayList<>(query1.list());
    list.addAll(query2.list());
    return list;
  }

  public List<DataOverlay> getDataOverlayByOwner(final User user) {
    return getElementsByParameter("creator_id", user.getId());
  }

  public void deleteDataOverlays(final List<DataOverlay> dataOverlays) {
    for (final DataOverlay dataOverlay : dataOverlays) {
      delete(dataOverlay);
    }
  }

}
