package lcsb.mapviewer.services.interfaces;

import java.util.List;

import lcsb.mapviewer.common.IProgressUpdater;
import lcsb.mapviewer.model.map.kinetics.SbmlParameter;
import lcsb.mapviewer.model.map.kinetics.SbmlUnit;
import lcsb.mapviewer.model.map.model.Model;
import lcsb.mapviewer.model.map.model.ModelData;
import lcsb.mapviewer.services.ObjectNotFoundException;
import lcsb.mapviewer.services.QueryException;

/**
 * Service that manages models (maps).
 * 
 * @author Piotr Gawron
 * 
 */
public interface IModelService {

  /**
   * Caches information about all pubmed articles for the given model.
   * 
   * @param model
   *          model in which we are caching the data
   * @param updater
   *          callback interface that update progress information
   */
  void cacheAllPubmedIds(final Model model, final IProgressUpdater updater);

  /**
   * Caches information about all miriam resources in the model.
   * 
   * @param model
   *          model in which we are caching the data
   * @param updater
   *          callback interface that update progress information
   */
  void cacheAllMiriamLinks(final Model model, final IProgressUpdater updater);

  void updateModel(final ModelData model);

  List<ModelData> getModelsByProjectId(final String projectId) throws ObjectNotFoundException;

  List<ModelData> getModelsByMapId(final String projectId, final String mapId) throws QueryException;

  ModelData getModelByMapId(final String projectId, final int mapId) throws QueryException;

  Model getAndFetchModelByMapId(final String projectId, final int mapId) throws QueryException;

  List<SbmlParameter> getParametersForModel(final String projectId, final String mapId) throws QueryException;

  int getPublicationCount(final String projectId, final String mapId) throws QueryException;

  List<SbmlUnit> getUnitsForModel(final String projectId, final String modelId) throws QueryException;
}
