package lcsb.mapviewer.services.interfaces;

import java.awt.geom.Point2D;
import java.util.Collection;
import java.util.List;

import lcsb.mapviewer.model.map.BioEntity;
import lcsb.mapviewer.services.QueryException;

/**
 * Service that gives access to search functionalities.
 * 
 * @author Piotr Gawron
 * 
 */
public interface ISearchService {

  /**
   * Search for elements on the map by query. Returns many possibilities from best
   * matching to less matching possibility.
   * 
   * @param projectId
   *          projectId on which we perform search
   * @param query
   *          the query
   * @param limit
   *          maximum number of results
   * @param perfectMatch
   *          should the match be perfect
   * @param ipAddress
   *          ip address of a client who is searching (used for logging purpose)
   * @return list of objects that matches the query sorted by the match quality
   */
  List<BioEntity> searchByQuery(final String projectId, final String mapId, final String query, final int limit, final boolean perfectMatch,
      final String ipAddress) throws QueryException;

  List<BioEntity> searchByQuery(final String projectId, final String mapId, final String query, final int limit, final boolean perfectMatch)
      throws QueryException;

  /**
   * Returns the closest elements to the coordinates on the model.
   * 
   * @param projectId
   *          projectId on which the search is performed
   * @param point
   *          coordinates where search is performed
   * @param numberOfElements
   *          how many closest elements should be returned
   * @return list of the closest elements
   */
  List<BioEntity> getClosestElements(final String projectId, final int mapId, final Point2D point, final int numberOfElements,
      final boolean perfectHit,
      final Collection<String> types) throws QueryException;

  List<String> getSuggestedQueryList(final String projectId) throws QueryException;

}
