package lcsb.mapviewer.services.impl;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertNull;

import java.util.List;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.springframework.test.annotation.Rollback;

import lcsb.mapviewer.common.Configuration;
import lcsb.mapviewer.model.Project;
import lcsb.mapviewer.model.security.PrivilegeType;
import lcsb.mapviewer.model.user.ConfigurationElementType;
import lcsb.mapviewer.model.user.ConfigurationOption;
import lcsb.mapviewer.services.ServiceTestFunctions;

@Rollback(true)
public class ConfigurationServiceTest extends ServiceTestFunctions {

  @Before
  public void setUp() throws Exception {
    // clear information about git version
    Configuration.getSystemBuildVersion(null, true);
  }

  @After
  public void tearDown() throws Exception {
    // clear information about git version
    Configuration.getSystemBuildVersion(null, true);
  }

  @Test
  public void testGetUpdate() throws Exception {
    String address = configurationService.getConfigurationValue(ConfigurationElementType.EMAIL_ADDRESS);
    configurationService.deleteConfigurationValue(ConfigurationElementType.EMAIL_ADDRESS);
    String newAddress = configurationService.getConfigurationValue(ConfigurationElementType.EMAIL_ADDRESS);
    assertEquals(ConfigurationElementType.EMAIL_ADDRESS.getDefaultValue(), newAddress);
    configurationService.setConfigurationValue(ConfigurationElementType.EMAIL_ADDRESS, "hello@world");
    newAddress = configurationService.getConfigurationValue(ConfigurationElementType.EMAIL_ADDRESS);
    assertEquals("hello@world", newAddress);

    configurationService.setConfigurationValue(ConfigurationElementType.EMAIL_ADDRESS, address);
  }

  @Test
  public void testList() throws Exception {
    List<ConfigurationOption> list = configurationService.getAllValues();
    assertEquals(ConfigurationElementType.values().length, list.size());
  }

  @Test
  public void testGetConfiguratioElemntForPrivilege() throws Exception {
    for (final PrivilegeType type : PrivilegeType.values()) {
      ConfigurationOption value = configurationService.getValue(type);
      if (Project.class.equals(type.getPrivilegeObjectType()) || type.equals(PrivilegeType.CAN_CREATE_OVERLAYS)) {
        assertNotNull("No default value for privilege " + type.getDescription(), value);
        assertNotNull(value.getValue());
      } else {
        assertNull(value);
      }
    }
  }

}
