package lcsb.mapviewer.services.impl;

import static org.junit.Assert.assertEquals;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.annotation.Rollback;

import lcsb.mapviewer.model.map.model.ModelData;
import lcsb.mapviewer.model.map.species.Element;
import lcsb.mapviewer.persist.dao.map.species.ElementProperty;
import lcsb.mapviewer.services.ObjectNotFoundException;
import lcsb.mapviewer.services.QueryException;
import lcsb.mapviewer.services.ServiceTestFunctions;
import lcsb.mapviewer.services.interfaces.IElementService;
import lcsb.mapviewer.services.interfaces.IModelService;

@Rollback(true)
public class ElementServiceTest extends ServiceTestFunctions {


  @Autowired
  private IElementService elementService;

  @Autowired
  private IModelService modelService;

  @Before
  public void setUp() throws Exception {
  }

  @After
  public void tearDown() throws Exception {
  }

  @Test(expected = ObjectNotFoundException.class)
  public void testGetElementsByNonExistingProject() throws Exception {
    List<ModelData> maps = modelService.getModelsByMapId("bla", "*");

    Map<ElementProperty, List<? extends Object>> filter = new HashMap<>();
    filter.put(ElementProperty.MAP, maps);

    elementService.getElementsByFilter(filter);
  }

  @Test
  public void testGetElementsByExistingProject() throws Exception {
    List<ModelData> maps = modelService.getModelsByMapId(BUILT_IN_MAP, "*");
    Map<ElementProperty, List<? extends Object>> filter = new HashMap<>();
    filter.put(ElementProperty.MAP, maps);

    List<Element> elements = elementService.getElementsByFilter(filter);
    assertEquals(0, elements.size());
  }

  @Test(expected = ObjectNotFoundException.class)
  public void testGetElementsByNonExistingMapId() throws Exception {
    List<ModelData> maps = modelService.getModelsByMapId(BUILT_IN_MAP, "0");
    Map<ElementProperty, List<? extends Object>> filter = new HashMap<>();
    filter.put(ElementProperty.MAP, maps);

    List<Element> elements = elementService.getElementsByFilter(filter);
    assertEquals(0, elements.size());
  }

  @Test(expected = QueryException.class)
  public void testGetElementsByInvalidMapId() throws Exception {
    List<ModelData> maps = modelService.getModelsByMapId(BUILT_IN_MAP, "bla");
    Map<ElementProperty, List<? extends Object>> filter = new HashMap<>();
    filter.put(ElementProperty.MAP, maps);

    List<Element> elements = elementService.getElementsByFilter(filter);
    assertEquals(0, elements.size());
  }

}
