package lcsb.mapviewer.web;

import static org.springframework.restdocs.mockmvc.MockMvcRestDocumentation.document;
import static org.springframework.restdocs.mockmvc.RestDocumentationRequestBuilders.get;
import static org.springframework.restdocs.payload.PayloadDocumentation.fieldWithPath;
import static org.springframework.restdocs.payload.PayloadDocumentation.responseFields;
import static org.springframework.restdocs.payload.PayloadDocumentation.subsectionWithPath;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.mock.web.MockHttpSession;
import org.springframework.restdocs.payload.ResponseFieldsSnippet;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.test.web.servlet.RequestBuilder;

@RunWith(SpringJUnit4ClassRunner.class)
public class MiRnaControllerIntegrationTest extends ControllerIntegrationTest {


  @Before
  public void setup() {
  }

  @Test
  public void testSearchMiRnasInProjectUrl() throws Exception {
    MockHttpSession session = createSession(BUILT_IN_TEST_ADMIN_LOGIN, BUILT_IN_TEST_ADMIN_PASSWORD);

    RequestBuilder request = get("/api/projects/{projectId}/miRnas:search?query=hsa-miR-125a-3p", BUILT_IN_PROJECT)
        .session(session);

    mockMvc.perform(request)
        .andExpect(status().is2xxSuccessful())
        .andDo(document("projects/project_mirna/search_by_query",
            getProjectPathParameters(),
            getChemicalFilter(),
            listOfMiRnaFields()));
  }

  @Test
  public void testSearchMiRnasInUndefinedProject() throws Exception {
    MockHttpSession session = createSession(BUILT_IN_TEST_ADMIN_LOGIN, BUILT_IN_TEST_ADMIN_PASSWORD);

    RequestBuilder request = get("/api/projects/*/miRnas:search?query=xyz")
        .session(session);

    mockMvc.perform(request)
        .andExpect(status().isNotFound());
  }

  @Test
  public void testSearchMiRnasByTargetInUndefinedProject() throws Exception {
    MockHttpSession session = createSession(BUILT_IN_TEST_ADMIN_LOGIN, BUILT_IN_TEST_ADMIN_PASSWORD);

    RequestBuilder request = get("/api/projects/*/miRnas:search?target=ALIAS:123")
        .session(session);

    mockMvc.perform(request)
        .andExpect(status().isNotFound());
  }

  @Test
  public void testGetSuggestedList() throws Exception {
    MockHttpSession session = createSession(BUILT_IN_TEST_ADMIN_LOGIN, BUILT_IN_TEST_ADMIN_PASSWORD);

    RequestBuilder request = get("/api/projects/{projectId}/miRnas/suggestedQueryList", BUILT_IN_PROJECT)
        .session(session);

    mockMvc.perform(request)
        .andDo(document("projects/project_mirna/suggested_query_list",
            getProjectPathParameters(),
            responseFields(
                fieldWithPath("[]")
                    .description("list of suggested mirna queries")
                    .type("array<string>"))))
        .andExpect(status().is2xxSuccessful())
        .andReturn().getResponse().getContentAsString();
  }

  @Test
  public void testGetSuggestedListForUndefinedProject() throws Exception {
    MockHttpSession session = createSession(BUILT_IN_TEST_ADMIN_LOGIN, BUILT_IN_TEST_ADMIN_PASSWORD);

    RequestBuilder request = get("/api/projects/*/miRnas/suggestedQueryList")
        .session(session);

    mockMvc.perform(request)
        .andExpect(status().isNotFound());
  }

  private ResponseFieldsSnippet listOfMiRnaFields() {
    return responseFields(
        subsectionWithPath("[].id")
            .description("identifier of the mirna")
            .type("object"),
        fieldWithPath("[].name")
            .description("name")
            .type("string"),
        fieldWithPath("[].targets")
            .description("list of targets")
            .type("array<Target>"),
        fieldWithPath("[].targets[].name")
            .description("target name")
            .type("string"),
        subsectionWithPath("[].targets[].references")
            .description("list of target references")
            .type("array<Reference>"),
        subsectionWithPath("[].targets[].targetElements")
            .description("list of elements on the map associated with this target")
            .type("array<object>"),
        subsectionWithPath("[].targets[].targetParticipants")
            .description("list of identifiers associated with this target")
            .type("array<object>"));
  }

}
