package lcsb.mapviewer.web;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotEquals;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.patch;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.post;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.apache.commons.lang3.mutable.MutableBoolean;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.util.EntityUtils;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.mock.web.MockHttpSession;
import org.springframework.test.annotation.Rollback;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.test.web.servlet.RequestBuilder;

import lcsb.mapviewer.services.interfaces.IUserService;

@RunWith(SpringJUnit4ClassRunner.class)
@Rollback
public class UserControllerIntegrationTestWithoutTransaction extends ControllerIntegrationTest {

  private static final String TEST_USER_PASSWORD = "test_pass";
  private static final String TEST_USER_LOGIN = "test_user";

  @Autowired
  private IUserService userService;

  @Before
  public void setup() {
  }

  @Test
  public void createUser() throws Exception {
    try {
      MockHttpSession session = createSession(BUILT_IN_TEST_ADMIN_LOGIN, BUILT_IN_TEST_ADMIN_PASSWORD);

      String body = EntityUtils.toString(new UrlEncodedFormEntity(Arrays.asList(
          new BasicNameValuePair("login", TEST_USER_LOGIN),
          new BasicNameValuePair("password", TEST_USER_PASSWORD),
          new BasicNameValuePair("name", ""),
          new BasicNameValuePair("surname", ""),
          new BasicNameValuePair("email", ""))));
      RequestBuilder request = post("/api/users/" + TEST_USER_LOGIN)
          .contentType(MediaType.APPLICATION_FORM_URLENCODED)
          .content(body)
          .session(session);

      mockMvc.perform(request)
          .andExpect(status().is2xxSuccessful());
    } finally {
      removeUser(userService.getUserByLogin(TEST_USER_LOGIN));
    }
  }

  @Test
  public void createGuiPreferencesTwice() throws Exception {
    MockHttpSession session = createSession(BUILT_IN_TEST_ADMIN_LOGIN, BUILT_IN_TEST_ADMIN_PASSWORD);

    try {
      createUser(TEST_USER_LOGIN, TEST_USER_PASSWORD);

      RequestBuilder request = patch("/api/users/" + TEST_USER_LOGIN + ":updatePreferences")
          .contentType(MediaType.APPLICATION_JSON)
          .content("{\"preferences\":{}}")
          .session(session);

      mockMvc.perform(request)
          .andExpect(status().is2xxSuccessful());

      MutableBoolean exceptionHappened = new MutableBoolean(false);

      List<Thread> threads = new ArrayList<>();
      for (int i = 0; i < 10; i++) {
        String body = "{\"preferences\":{\"gui-preferences\":{\"test\":\"val" + i + "\"}}}";
        Thread thread = new Thread(new Runnable() {

          @Override
          public void run() {
            try {
              RequestBuilder request = patch("/api/users/" + TEST_USER_LOGIN + ":updatePreferences")
                  .contentType(MediaType.APPLICATION_JSON)
                  .content(body)
                  .session(session);

              int status = mockMvc.perform(request).andReturn().getResponse().getStatus();
              assertNotEquals(500, status);
            } catch (final Throwable e) {
              e.printStackTrace();
              exceptionHappened.setTrue();
            }
          }
        });
        threads.add(thread);
        thread.start();
      }
      for (final Thread thread : threads) {
        thread.join();
      }
      assertFalse(exceptionHappened.getValue());
    } finally {
      removeUser(userService.getUserByLogin(TEST_USER_LOGIN));
    }
  }
}
