package lcsb.mapviewer.web.utils;

import java.util.List;

import org.springframework.restdocs.cli.CommandFormatter;
import org.springframework.util.CollectionUtils;

import lcsb.mapviewer.common.Configuration;

/**
 * This is a class for workaround the issue that when we put content of file
 * inside the request we would like to provide human readable curl request.In
 * such cases the curl example should not contain content of the file but simple
 * reference @filename. The filename is taken from header "post-filename" which
 * will be removed from the curl sample.
 * 
 * @author Piotr Gawron
 *
 */
public class CommandFormatterWithReplacingPostFilenameHeader implements CommandFormatter {

  private String separator;

  /**
   * Information if in the formatted list of string there should also be
   * information about session.
   */
  private boolean session = false;

  public CommandFormatterWithReplacingPostFilenameHeader(final String separator) {
    this.separator = separator;
  }

  /**
   * Concatenates a list of {@code String}s with a specified separator.
   * 
   * @param elements
   *          a list of {@code String}s to be concatenated
   * @return concatenated list of {@code String}s as one {@code String}
   */
  @Override
  public String format(final List<String> elements) {
    if (CollectionUtils.isEmpty(elements)) {
      return "";
    }
    String contentFileName = null;
    for (final String element : elements) {
      if (element.startsWith("-H 'post-filename:")) {
        contentFileName = element.replace("-H 'post-filename: ", "").replace("'", "");
      }
    }
    if (session) {
      elements.add("--cookie \"" + Configuration.AUTH_TOKEN + "=xxxxxxxx\"");
    }

    StringBuilder result = new StringBuilder();
    for (String element : elements) {
      if (element.startsWith("-d") && contentFileName != null) {
        element = "--data-binary @" + contentFileName;
      }
      if (!element.startsWith("-H 'post-filename:")) {
        result.append(String.format(this.separator));
        result.append(element);
      }
    }
    return result.toString();
  }

  public void setSessionAvailable(final boolean session) {
    this.session = session;
  }

}